# Simulation Visualizer

TypeScript CLI for generating interactive HTML visualizations of mobile robot simulations. This visualizer
is primarily meant to work with the accompanying Python API.

## Prerequisites

- [pnpm](https://pnpm.io/) for package management 

## Setup

```bash
pnpm install && pnpm build
```
